#!/bin/bash

#
# Copyright (c) 2022 VMware, Inc. All rights reserved.
#

echo "Bootstrapping the service"
: ${SERVICE_JAR_PATH:="/code/service.jar"}
: ${XMX_VALUE:="2048m"}
: ${XMS_VALUE:="1024m"}
: ${ENABLE_JMX:="false"}
: ${JMX_PORT:="9876"}
: ${JAVA_ENABLE_DEBUG:="false"}
: ${JAVA_DEBUG_PORT:="1035"}
: ${DEBUG_OPTS:="-agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=*:${JAVA_DEBUG_PORT}"}
: ${JMX_OPTS:="-Dcom.sun.management.jmxremote \
               -Dcom.sun.management.jmxremote.authenticate=false \
               -Dcom.sun.management.jmxremote.ssl=false \
               -Dcom.sun.management.jmxremote.local.only=false \
               -Dcom.sun.management.jmxremote.port=${JMX_PORT} \
               -Dcom.sun.management.jmxremote.rmi.port=${JMX_PORT} \
               -Djava.rmi.server.hostname=localhost"}

: ${JAVA_OPTS:="-XX:+UseG1GC \
                -XX:+UseStringDeduplication"}

JAVA_OPTS=" -Xmx${XMX_VALUE} -Xms${XMS_VALUE} "${JAVA_OPTS}

if [[ "${JAVA_ENABLE_DEBUG}" == "true" ]];
then
  echo "Enabling debug options. Remote debug port is "${JAVA_DEBUG_PORT}
  JAVA_OPTS=${JAVA_OPTS}" "${DEBUG_OPTS}
fi

if [[ "${ENABLE_JMX}" == "true" ]];
then
  echo "Enabling JMX options. Remote JMX port is "${JMX_PORT}
  JAVA_OPTS=${JAVA_OPTS}" "${JMX_OPTS}
fi

echo "JAVA_OPTS="${JAVA_OPTS}
exec java ${JAVA_OPTS} -jar ${SERVICE_JAR_PATH}
